"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
const getContent_1 = require("./getContent");
const path = require('canonical-path');
describe('getContent', () => {
    let parser;
    let basePath;
    beforeEach(() => {
        parser = new _1.TsParser(require('dgeni/lib/mocks/log')(false));
        basePath = path.resolve(__dirname, '../../mocks');
    });
    it('should get the leading jsdoc comments for exports', () => {
        const parseInfo = parser.parse(['tsParser/getContent.test.ts'], basePath);
        const module = parseInfo.moduleSymbols[0];
        const comments = module.exportArray.map(e => getContent_1.getContent(e.getDeclarations()[0]));
        expect(comments.length).toEqual(2);
        expect(comments).toContain('Description of TestClass\n@deprecated warning');
        expect(comments).toContain('Description of function');
    });
    it('should get the leading jsdoc comments for class members and their parameters', () => {
        const parseInfo = parser.parse(['tsParser/getContent.test.ts'], basePath);
        const module = parseInfo.moduleSymbols[0];
        const classDoc = module.exportArray.find(e => e.name === 'TestClass');
        expect(getContent_1.getContent(classDoc.members.get('property').valueDeclaration)).toEqual('Some property');
        const method = classDoc.members.get('method').valueDeclaration;
        expect(getContent_1.getContent(method)).toEqual('Some method');
        expect(getContent_1.getContent(method.parameters[0])).toEqual('param 1');
    });
    it('should properly concatenate multiple leading comments', () => {
        const parseInfo = parser.parse(['tsParser/multipleLeadingComments.ts'], basePath);
        const module = parseInfo.moduleSymbols[0];
        expect(getContent_1.getContent(module.exportArray[0].getDeclarations()[0])).toEqual('Not a license comment.\nThis is a test function');
    });
    describe('leading comments concatenation disabled', () => {
        it('should be able to disable concatenation', () => {
            const parseInfo = parser.parse(['tsParser/multipleLeadingComments.ts'], basePath);
            const module = parseInfo.moduleSymbols[0];
            expect(getContent_1.getContent(module.exportArray[0].getDeclarations()[0], false))
                .toEqual('This is a test function');
        });
        it('should not throw if node does not have any leading comment', () => {
            const parseInfo = parser.parse(['tsParser/multipleLeadingComments.ts'], basePath);
            const module = parseInfo.moduleSymbols[0];
            expect(() => getContent_1.getContent(module.exportArray[1].getDeclarations()[0], false))
                .not.toThrow();
        });
        it('should skip leading single-line comments', () => {
            const parseInfo = parser.parse(['tsParser/multipleLeadingComments.ts'], basePath);
            const module = parseInfo.moduleSymbols[0];
            expect(getContent_1.getContent(module.exportArray[2].getDeclarations()[0], false))
                .toEqual('This is the real comment.');
        });
        it('should skip leading non-js multi line comments', () => {
            const parseInfo = parser.parse(['tsParser/multipleLeadingComments.ts'], basePath);
            const module = parseInfo.moduleSymbols[0];
            expect(getContent_1.getContent(module.exportArray[3].getDeclarations()[0], false))
                .toEqual('First real comment.');
        });
    });
});
//# sourceMappingURL=getContent.spec.js.map