"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
const getDeclarationTypeText_1 = require("./getDeclarationTypeText");
const path = require('canonical-path');
describe('getDeclarationTypeText', () => {
    let parser;
    let basePath;
    beforeEach(() => {
        parser = new _1.TsParser(require('dgeni/lib/mocks/log')(false));
        basePath = path.resolve(__dirname, '../../mocks');
    });
    it('should return a textual representation of the type the declaration', () => {
        const parseInfo = parser.parse(['tsParser/getDeclarationTypeText.test.ts'], basePath);
        const moduleExports = parseInfo.moduleSymbols[0].exportArray;
        expect(getDeclarationTypeText_1.getDeclarationTypeText(getExport('testConst').getDeclarations()[0])).toEqual('42');
        const testFunction = getExport('testFunction').getDeclarations()[0];
        expect(getDeclarationTypeText_1.getDeclarationTypeText(testFunction)).toEqual('number');
        expect(getDeclarationTypeText_1.getDeclarationTypeText(testFunction.parameters[0])).toEqual('T[]');
        expect(getDeclarationTypeText_1.getDeclarationTypeText(testFunction.typeParameters[0])).toEqual('T');
        const testClass = getExport('TestClass');
        const testClassDeclaration = testClass.getDeclarations()[0];
        expect(getDeclarationTypeText_1.getDeclarationTypeText(testClass.members.get('prop1').getDeclarations()[0])).toEqual('T[]');
        expect(getDeclarationTypeText_1.getDeclarationTypeText(testClass.members.get('prop2').getDeclarations()[0])).toEqual('OtherClass<T>');
        expect(getDeclarationTypeText_1.getDeclarationTypeText(testClass.members.get('prop3').getDeclarations()[0])).toEqual('OtherClass<T, T>');
        expect(getDeclarationTypeText_1.getDeclarationTypeText(testClass.members.get('method').getDeclarations()[0])).toEqual('T');
        expect(getDeclarationTypeText_1.getDeclarationTypeText(testClassDeclaration.typeParameters[0])).toEqual('T = any');
        function getExport(name) {
            return moduleExports.find(e => e.name === name);
        }
    });
});
//# sourceMappingURL=getDeclarationTypeText.spec.js.map