"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_1 = require("typescript");
const LineFeedPrinter_1 = require("./LineFeedPrinter");
const nodeToString_1 = require("./nodeToString");
function getDecorators(declaration) {
    if (declaration.decorators) {
        return declaration.decorators.map(decorator => {
            const callExpression = getCallExpression(decorator);
            if (callExpression) {
                return {
                    argumentInfo: callExpression.arguments.map(argument => parseArgument(argument)),
                    arguments: callExpression.arguments.map(argument => LineFeedPrinter_1.lineFeedPrinter.printNode(typescript_1.EmitHint.Expression, argument, declaration.getSourceFile())),
                    expression: decorator,
                    isCallExpression: true,
                    name: nodeToString_1.nodeToString(callExpression.expression),
                };
            }
            else {
                return {
                    expression: decorator,
                    isCallExpression: false,
                    name: nodeToString_1.nodeToString(decorator.expression),
                };
            }
        });
    }
}
exports.getDecorators = getDecorators;
function getCallExpression(decorator) {
    if (decorator.expression.kind === typescript_1.SyntaxKind.CallExpression) {
        return decorator.expression;
    }
}
function parseProperties(properties) {
    const result = {};
    properties.forEach(property => {
        if (property.kind === typescript_1.SyntaxKind.PropertyAssignment) {
            result[nodeToString_1.nodeToString(property.name)] = parseArgument(property.initializer);
        }
    });
    return result;
}
function parseArgument(argument) {
    if (argument.kind === typescript_1.SyntaxKind.ObjectLiteralExpression) {
        return parseProperties(argument.properties);
    }
    if (argument.kind === typescript_1.SyntaxKind.ArrayLiteralExpression) {
        return argument.elements.map(element => nodeToString_1.nodeToString(element));
    }
    return nodeToString_1.nodeToString(argument);
}
//# sourceMappingURL=getDecorators.js.map