"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
const getTypeText_1 = require("./getTypeText");
const path = require('canonical-path');
describe('getTypeText', () => {
    let parser;
    let basePath;
    beforeEach(() => {
        parser = new _1.TsParser(require('dgeni/lib/mocks/log')(false));
        basePath = path.resolve(__dirname, '../../mocks');
    });
    it('should return text representation of types', () => {
        const parseInfo = parser.parse(['tsParser/getTypeText.test.ts'], basePath);
        const moduleExports = parseInfo.moduleSymbols[0].exportArray;
        expect(moduleExports.length).toEqual(13);
        const types = moduleExports.map(e => [e.name, getType(e) && getTypeText_1.getTypeText(getType(e))]);
        expect(types).toContain(['TestType', 'TestClass']);
        expect(types).toContain(['testFunction', 'string']);
        expect(types).toContain(['testConst', 'number']);
        expect(types).toContain(['testLet', 'TestType']);
        expect(types).toContain(['TestUnion', 'TestClass | string']);
        expect(types).toContain(['TestLiteral', [
                '{',
                '    x: number;',
                '    y: string;',
                '}',
            ].join('\n')]);
        expect(types).toContain(['TestGeneric1', 'Array<string>']);
        expect(types).toContain(['TestGeneric2', 'Array<T>']);
    });
    it('should remove comments from the rendered text', () => {
        const parseInfo = parser.parse(['tsParser/getTypeText.test.ts'], basePath);
        const moduleExports = parseInfo.moduleSymbols[0].exportArray;
        const testType2 = moduleExports.find(e => e.name === 'TestType2');
        expect(getTypeText_1.getTypeText(getType(testType2))).toEqual([
            '{',
            '    a: number;',
            '    b: string;',
            '} & {',
            '    a: string;',
            '}',
        ].join('\n'));
    });
});
function getType(symbol) {
    return symbol.getDeclarations()[0].type;
}
//# sourceMappingURL=getTypeText.spec.js.map